"use strict";(self.webpackChunkknx_frontend=self.webpackChunkknx_frontend||[]).push([[1382],{41382:function(e,t,n){n.r(t),n.d(t,{HaTriggerSelector:function(){return f}});var r,a,i,o=n(6238),l=n(36683),d=n(89231),s=n(29864),u=n(83647),c=n(8364),h=(n(77052),n(98597)),k=n(196),f=(n(79674),(0,c.A)([(0,k.EM)("ha-selector-trigger")],(function(e,t){var n=function(t){function n(){var t;(0,d.A)(this,n);for(var r=arguments.length,a=new Array(r),i=0;i<r;i++)a[i]=arguments[i];return t=(0,s.A)(this,n,[].concat(a)),e(t),t}return(0,u.A)(n,t),(0,l.A)(n)}(t);return{F:n,d:[{kind:"field",decorators:[(0,k.MZ)({attribute:!1})],key:"hass",value:void 0},{kind:"field",decorators:[(0,k.MZ)({attribute:!1})],key:"selector",value:void 0},{kind:"field",decorators:[(0,k.MZ)({attribute:!1})],key:"value",value:void 0},{kind:"field",decorators:[(0,k.MZ)()],key:"label",value:void 0},{kind:"field",decorators:[(0,k.MZ)({type:Boolean,reflect:!0})],key:"disabled",value:function(){return!1}},{kind:"method",key:"render",value:function(){var e;return(0,h.qy)(r||(r=(0,o.A)(["\n      ","\n      <ha-automation-trigger\n        .disabled=","\n        .triggers=","\n        .hass=","\n        .path=","\n      ></ha-automation-trigger>\n    "])),this.label?(0,h.qy)(a||(a=(0,o.A)(["<label>","</label>"])),this.label):h.s6,this.disabled,this.value||[],this.hass,null===(e=this.selector.trigger)||void 0===e?void 0:e.path)}},{kind:"get",static:!0,key:"styles",value:function(){return(0,h.AH)(i||(i=(0,o.A)(["\n      ha-automation-trigger {\n        display: block;\n        margin-bottom: 16px;\n      }\n      label {\n        display: block;\n        margin-bottom: 4px;\n        font-weight: 500;\n      }\n    "])))}}]}}),h.WF))}}]);