"use strict";(self.webpackChunkknx_frontend=self.webpackChunkknx_frontend||[]).push([[6048],{66048:function(e,n,t){t.r(n),t.d(n,{HaFormExpendable:function(){return k}});var a,i,o,r,c,s=t(95803),d=t(6238),l=t(36683),h=t(89231),u=t(29864),p=t(83647),m=t(8364),v=(t(77052),t(848),t(43859),t(68113),t(58971),t(98597)),f=t(196),k=(t(93259),(0,m.A)([(0,f.EM)("ha-form-expandable")],(function(e,n){var t=function(n){function t(){var n;(0,h.A)(this,t);for(var a=arguments.length,i=new Array(a),o=0;o<a;o++)i[o]=arguments[o];return n=(0,u.A)(this,t,[].concat(i)),e(n),n}return(0,p.A)(t,n),(0,l.A)(t)}(n);return{F:t,d:[{kind:"field",decorators:[(0,f.MZ)({attribute:!1})],key:"hass",value:void 0},{kind:"field",decorators:[(0,f.MZ)({attribute:!1})],key:"data",value:void 0},{kind:"field",decorators:[(0,f.MZ)({attribute:!1})],key:"schema",value:void 0},{kind:"field",decorators:[(0,f.MZ)({type:Boolean})],key:"disabled",value:function(){return!1}},{kind:"field",decorators:[(0,f.MZ)({attribute:!1})],key:"computeLabel",value:void 0},{kind:"field",decorators:[(0,f.MZ)({attribute:!1})],key:"computeHelper",value:void 0},{kind:"method",key:"_renderDescription",value:function(){var e,n=null===(e=this.computeHelper)||void 0===e?void 0:e.call(this,this.schema);return n?(0,v.qy)(a||(a=(0,d.A)(["<p>","</p>"])),n):v.s6}},{kind:"field",key:"_computeLabel",value:function(){var e=this;return function(n,t,a){return e.computeLabel?e.computeLabel(n,t,Object.assign(Object.assign({},a),{},{path:[].concat((0,s.A)((null==a?void 0:a.path)||[]),[e.schema.name])})):e.computeLabel}}},{kind:"field",key:"_computeHelper",value:function(){var e=this;return function(n,t){return e.computeHelper?e.computeHelper(n,Object.assign(Object.assign({},t),{},{path:[].concat((0,s.A)((null==t?void 0:t.path)||[]),[e.schema.name])})):e.computeHelper}}},{kind:"method",key:"render",value:function(){var e,n,t;return(0,v.qy)(i||(i=(0,d.A)(["\n      <ha-expansion-panel outlined .expanded=",'>\n        <div\n          slot="header"\n          role="heading"\n          aria-level=',"\n        >\n          ","\n          ",'\n        </div>\n        <div class="content">\n          ',"\n          <ha-form\n            .hass=","\n            .data=","\n            .schema=","\n            .disabled=","\n            .computeLabel=","\n            .computeHelper=","\n          ></ha-form>\n        </div>\n      </ha-expansion-panel>\n    "])),Boolean(this.schema.expanded),null!==(e=null===(n=this.schema.headingLevel)||void 0===n?void 0:n.toString())&&void 0!==e?e:"3",this.schema.icon?(0,v.qy)(o||(o=(0,d.A)([" <ha-icon .icon=","></ha-icon> "])),this.schema.icon):this.schema.iconPath?(0,v.qy)(r||(r=(0,d.A)(["\n                  <ha-svg-icon .path=","></ha-svg-icon>\n                "])),this.schema.iconPath):v.s6,this.schema.title||(null===(t=this.computeLabel)||void 0===t?void 0:t.call(this,this.schema)),this._renderDescription(),this.hass,this.data,this.schema.schema,this.disabled,this._computeLabel,this._computeHelper)}},{kind:"get",static:!0,key:"styles",value:function(){return(0,v.AH)(c||(c=(0,d.A)(["\n      :host {\n        display: flex !important;\n        flex-direction: column;\n      }\n      :host ha-form {\n        display: block;\n      }\n      .content {\n        padding: 12px;\n      }\n      .content p {\n        margin: 0 0 24px;\n      }\n      ha-expansion-panel {\n        display: block;\n        --expansion-panel-content-padding: 0;\n        border-radius: 6px;\n        --ha-card-border-radius: 6px;\n      }\n      ha-svg-icon,\n      ha-icon {\n        color: var(--secondary-text-color);\n      }\n    "])))}}]}}),v.WF))}}]);