"use strict";(self.webpackChunkknx_frontend=self.webpackChunkknx_frontend||[]).push([[7150],{47150:function(e,n,t){t.r(n),t.d(n,{HaFormBoolean:function(){return m}});var a=t(6238),i=t(36683),r=t(89231),o=t(29864),d=t(83647),u=t(8364),c=(t(77052),t(76513)),l=t(196),h=t(80487),f=t(4258),s=function(e){function n(){return(0,r.A)(this,n),(0,o.A)(this,n,arguments)}return(0,d.A)(n,e),(0,i.A)(n)}(h.M);s.styles=[f.R],s=(0,c.Cg)([(0,l.EM)("mwc-formfield")],s);var k,v=t(98597),b=t(33167),m=(t(19887),(0,u.A)([(0,l.EM)("ha-form-boolean")],(function(e,n){var t=function(n){function t(){var n;(0,r.A)(this,t);for(var a=arguments.length,i=new Array(a),d=0;d<a;d++)i[d]=arguments[d];return n=(0,o.A)(this,t,[].concat(i)),e(n),n}return(0,d.A)(t,n),(0,i.A)(t)}(n);return{F:t,d:[{kind:"field",decorators:[(0,l.MZ)({attribute:!1})],key:"schema",value:void 0},{kind:"field",decorators:[(0,l.MZ)({attribute:!1})],key:"data",value:void 0},{kind:"field",decorators:[(0,l.MZ)()],key:"label",value:void 0},{kind:"field",decorators:[(0,l.MZ)({type:Boolean})],key:"disabled",value:function(){return!1}},{kind:"field",decorators:[(0,l.P)("ha-checkbox",!0)],key:"_input",value:void 0},{kind:"method",key:"focus",value:function(){this._input&&this._input.focus()}},{kind:"method",key:"render",value:function(){return(0,v.qy)(k||(k=(0,a.A)(["\n      <mwc-formfield .label=",">\n        <ha-checkbox\n          .checked=","\n          .disabled=","\n          @change=","\n        ></ha-checkbox>\n      </mwc-formfield>\n    "])),this.label,this.data,this.disabled,this._valueChanged)}},{kind:"method",key:"_valueChanged",value:function(e){(0,b.r)(this,"value-changed",{value:e.target.checked})}}]}}),v.WF))}}]);