"use strict";(self.webpackChunkknx_frontend=self.webpackChunkknx_frontend||[]).push([[2724],{42724:function(n,e,t){t.r(e),t.d(e,{HaIconButtonArrowNext:function(){return h}});var o,r=t(6238),i=t(36683),a=t(89231),u=t(29864),d=t(83647),l=t(8364),c=(t(77052),t(98597)),s=t(196),f=t(10),h=(t(96396),(0,l.A)([(0,s.EM)("ha-icon-button-arrow-next")],(function(n,e){var t=function(e){function t(){var e;(0,a.A)(this,t);for(var o=arguments.length,r=new Array(o),i=0;i<o;i++)r[i]=arguments[i];return e=(0,u.A)(this,t,[].concat(r)),n(e),e}return(0,d.A)(t,e),(0,i.A)(t)}(e);return{F:t,d:[{kind:"field",decorators:[(0,s.MZ)({attribute:!1})],key:"hass",value:void 0},{kind:"field",decorators:[(0,s.MZ)({type:Boolean})],key:"disabled",value:function(){return!1}},{kind:"field",decorators:[(0,s.MZ)()],key:"label",value:void 0},{kind:"field",decorators:[(0,s.wk)()],key:"_icon",value:function(){return"rtl"===f.G.document.dir?"M20,11V13H8L13.5,18.5L12.08,19.92L4.16,12L12.08,4.08L13.5,5.5L8,11H20Z":"M4,11V13H16L10.5,18.5L11.92,19.92L19.84,12L11.92,4.08L10.5,5.5L16,11H4Z"}},{kind:"method",key:"render",value:function(){var n;return(0,c.qy)(o||(o=(0,r.A)(["\n      <ha-icon-button\n        .disabled=","\n        .label=","\n        .path=","\n      ></ha-icon-button>\n    "])),this.disabled,this.label||(null===(n=this.hass)||void 0===n?void 0:n.localize("ui.common.next"))||"Next",this._icon)}}]}}),c.WF))}}]);