export const id=96;export const ids=[96];export const modules={96:(e,t,o)=>{o.r(t),o.d(t,{HaIconButtonNext:()=>a});var n=o(5461),i=o(8597),d=o(196),r=o(10);o(6396);let a=(0,n.A)([(0,d.EM)("ha-icon-button-next")],(function(e,t){return{F:class extends t{constructor(...t){super(...t),e(this)}},d:[{kind:"field",decorators:[(0,d.MZ)({attribute:!1})],key:"hass",value:void 0},{kind:"field",decorators:[(0,d.MZ)({type:Boolean})],key:"disabled",value(){return!1}},{kind:"field",decorators:[(0,d.MZ)()],key:"label",value:void 0},{kind:"field",decorators:[(0,d.wk)()],key:"_icon",value(){return"rtl"===r.G.document.dir?"M15.41,16.58L10.83,12L15.41,7.41L14,6L8,12L14,18L15.41,16.58Z":"M8.59,16.58L13.17,12L8.59,7.41L10,6L16,12L10,18L8.59,16.58Z"}},{kind:"method",key:"render",value:function(){return i.qy`
      <ha-icon-button
        .disabled=${this.disabled}
        .label=${this.label||this.hass?.localize("ui.common.next")||"Next"}
        .path=${this._icon}
      ></ha-icon-button>
    `}}]}}),i.WF)}};
//# sourceMappingURL=m_Ts6yW9.js.map