export const id=4088;export const ids=[4088];export const modules={4088:(e,t,o)=>{o.r(t),o.d(t,{HaSelectorConstant:()=>a});var s=o(5461),l=o(8597),r=o(196);let a=(0,s.A)([(0,r.EM)("ha-selector-constant")],(function(e,t){return{F:class extends t{constructor(...t){super(...t),e(this)}},d:[{kind:"field",decorators:[(0,r.MZ)({attribute:!1})],key:"selector",value:void 0},{kind:"field",decorators:[(0,r.MZ)({type:Boolean})],key:"disabled",value(){return!1}},{kind:"field",decorators:[(0,r.MZ)({attribute:!1})],key:"localizeValue",value:void 0},{kind:"method",key:"render",value:function(){if(this.disabled)return l.s6;const e=this.selector.constant?.translation_key;return(e&&this.localizeValue?this.localizeValue(`${e}.value`):void 0)??this.selector.constant?.label??this.selector.constant?.value??l.s6}}]}}),l.WF)}};