"use strict";(self.webpackChunkknx_frontend=self.webpackChunkknx_frontend||[]).push([[4088],{94088:function(e,t,n){n.r(t),n.d(t,{HaSelectorConstant:function(){return s}});var o=n(36683),l=n(89231),r=n(29864),i=n(83647),a=n(8364),u=(n(77052),n(98597)),d=n(196),s=(0,a.A)([(0,d.EM)("ha-selector-constant")],(function(e,t){var n=function(t){function n(){var t;(0,l.A)(this,n);for(var o=arguments.length,i=new Array(o),a=0;a<o;a++)i[a]=arguments[a];return t=(0,r.A)(this,n,[].concat(i)),e(t),t}return(0,i.A)(n,t),(0,o.A)(n)}(t);return{F:n,d:[{kind:"field",decorators:[(0,d.MZ)({attribute:!1})],key:"selector",value:void 0},{kind:"field",decorators:[(0,d.MZ)({type:Boolean})],key:"disabled",value:function(){return!1}},{kind:"field",decorators:[(0,d.MZ)({attribute:!1})],key:"localizeValue",value:void 0},{kind:"method",key:"render",value:function(){var e,t,n,o,l;if(this.disabled)return u.s6;var r=null===(e=this.selector.constant)||void 0===e?void 0:e.translation_key,i=r&&this.localizeValue?this.localizeValue("".concat(r,".value")):void 0;return null!==(t=null!==(n=null!=i?i:null===(o=this.selector.constant)||void 0===o?void 0:o.label)&&void 0!==n?n:null===(l=this.selector.constant)||void 0===l?void 0:l.value)&&void 0!==t?t:u.s6}}]}}),u.WF)}}]);