export const id=2724;export const ids=[2724];export const modules={2724:(e,t,o)=>{o.r(t),o.d(t,{HaIconButtonArrowNext:()=>a});var n=o(5461),r=o(8597),i=o(196),d=o(10);o(6396);let a=(0,n.A)([(0,i.EM)("ha-icon-button-arrow-next")],(function(e,t){return{F:class extends t{constructor(...t){super(...t),e(this)}},d:[{kind:"field",decorators:[(0,i.MZ)({attribute:!1})],key:"hass",value:void 0},{kind:"field",decorators:[(0,i.MZ)({type:Boolean})],key:"disabled",value(){return!1}},{kind:"field",decorators:[(0,i.MZ)()],key:"label",value:void 0},{kind:"field",decorators:[(0,i.wk)()],key:"_icon",value(){return"rtl"===d.G.document.dir?"M20,11V13H8L13.5,18.5L12.08,19.92L4.16,12L12.08,4.08L13.5,5.5L8,11H20Z":"M4,11V13H16L10.5,18.5L11.92,19.92L19.84,12L11.92,4.08L10.5,5.5L16,11H4Z"}},{kind:"method",key:"render",value:function(){return r.qy`
      <ha-icon-button
        .disabled=${this.disabled}
        .label=${this.label||this.hass?.localize("ui.common.next")||"Next"}
        .path=${this._icon}
      ></ha-icon-button>
    `}}]}}),r.WF)}};
//# sourceMappingURL=nvXOgqs2.js.map