"use strict";(self.webpackChunkknx_frontend=self.webpackChunkknx_frontend||[]).push([[6880],{96880:function(e,t,n){n.r(t),n.d(t,{HaFormGrid:function(){return v}});var r,a,i,o=n(6238),d=n(94881),u=n(1781),s=n(36683),c=n(89231),l=n(29864),h=n(83647),m=n(8364),f=n(27526),p=(n(77052),n(36724),n(98168),n(93259),n(98597)),k=n(196),v=(0,m.A)([(0,k.EM)("ha-form-grid")],(function(e,t){var n,m=function(t){function n(){var t;(0,c.A)(this,n);for(var r=arguments.length,a=new Array(r),i=0;i<r;i++)a[i]=arguments[i];return t=(0,l.A)(this,n,[].concat(a)),e(t),t}return(0,h.A)(n,t),(0,s.A)(n)}(t);return{F:m,d:[{kind:"field",decorators:[(0,k.MZ)({attribute:!1})],key:"hass",value:void 0},{kind:"field",decorators:[(0,k.MZ)({attribute:!1})],key:"data",value:void 0},{kind:"field",decorators:[(0,k.MZ)({attribute:!1})],key:"schema",value:void 0},{kind:"field",decorators:[(0,k.MZ)({type:Boolean})],key:"disabled",value:function(){return!1}},{kind:"field",decorators:[(0,k.MZ)({attribute:!1})],key:"computeLabel",value:void 0},{kind:"field",decorators:[(0,k.MZ)({attribute:!1})],key:"computeHelper",value:void 0},{kind:"method",key:"focus",value:(n=(0,u.A)((0,d.A)().mark((function e(){var t;return(0,d.A)().wrap((function(e){for(;;)switch(e.prev=e.next){case 0:return e.next=2,this.updateComplete;case 2:null===(t=this.renderRoot.querySelector("ha-form"))||void 0===t||t.focus();case 3:case"end":return e.stop()}}),e,this)}))),function(){return n.apply(this,arguments)})},{kind:"method",key:"updated",value:function(e){(0,f.A)(m,"updated",this,3)([e]),e.has("schema")&&(this.schema.column_min_width?this.style.setProperty("--form-grid-min-width",this.schema.column_min_width):this.style.setProperty("--form-grid-min-width",""))}},{kind:"method",key:"render",value:function(){var e=this;return(0,p.qy)(r||(r=(0,o.A)(["\n      ","\n    "])),this.schema.schema.map((function(t){return(0,p.qy)(a||(a=(0,o.A)(["\n          <ha-form\n            .hass=","\n            .data=","\n            .schema=","\n            .disabled=","\n            .computeLabel=","\n            .computeHelper=","\n          ></ha-form>\n        "])),e.hass,e.data,[t],e.disabled,e.computeLabel,e.computeHelper)})))}},{kind:"get",static:!0,key:"styles",value:function(){return(0,p.AH)(i||(i=(0,o.A)(["\n      :host {\n        display: grid !important;\n        grid-template-columns: repeat(\n          var(--form-grid-column-count, auto-fit),\n          minmax(var(--form-grid-min-width, 200px), 1fr)\n        );\n        grid-column-gap: 8px;\n        grid-row-gap: 24px;\n      }\n      :host > ha-form {\n        display: block;\n      }\n    "])))}}]}}),p.WF)}}]);