"use strict";(self.webpackChunkknx_frontend=self.webpackChunkknx_frontend||[]).push([[3908],{73908:function(n,e,t){t.r(e),t.d(e,{HaFormConstant:function(){return h}});var a,r,o=t(6238),s=t(36683),i=t(89231),u=t(29864),c=t(83647),l=t(8364),d=(t(77052),t(98597)),f=t(196),h=(0,l.A)([(0,f.EM)("ha-form-constant")],(function(n,e){var t=function(e){function t(){var e;(0,i.A)(this,t);for(var a=arguments.length,r=new Array(a),o=0;o<a;o++)r[o]=arguments[o];return e=(0,u.A)(this,t,[].concat(r)),n(e),e}return(0,c.A)(t,e),(0,s.A)(t)}(e);return{F:t,d:[{kind:"field",decorators:[(0,f.MZ)({attribute:!1})],key:"schema",value:void 0},{kind:"field",decorators:[(0,f.MZ)()],key:"label",value:void 0},{kind:"method",key:"render",value:function(){return(0,d.qy)(a||(a=(0,o.A)(['<span class="label">',"</span>",""])),this.label,this.schema.value?": ".concat(this.schema.value):"")}},{kind:"get",static:!0,key:"styles",value:function(){return(0,d.AH)(r||(r=(0,o.A)(["\n      :host {\n        display: block;\n      }\n      .label {\n        font-weight: 500;\n      }\n    "])))}}]}}),d.WF)}}]);