export const id=3908;export const ids=[3908];export const modules={3908:(e,t,s)=>{s.r(t),s.d(t,{HaFormConstant:()=>l});var a=s(5461),n=s(8597),o=s(196);let l=(0,a.A)([(0,o.EM)("ha-form-constant")],(function(e,t){return{F:class extends t{constructor(...t){super(...t),e(this)}},d:[{kind:"field",decorators:[(0,o.MZ)({attribute:!1})],key:"schema",value:void 0},{kind:"field",decorators:[(0,o.MZ)()],key:"label",value:void 0},{kind:"method",key:"render",value:function(){return n.qy`<span class="label">${this.label}</span>${this.schema.value?`: ${this.schema.value}`:""}`}},{kind:"get",static:!0,key:"styles",value:function(){return n.AH`
      :host {
        display: block;
      }
      .label {
        font-weight: 500;
      }
    `}}]}}),n.WF)}};
//# sourceMappingURL=t3P_OFBd.js.map