"use strict";(self.webpackChunkknx_frontend=self.webpackChunkknx_frontend||[]).push([[6785],{67319:function(t,n,e){e.d(n,{S:function(){return o}});e(650),e(26777),e(47711),e(5462);var r={en:"US",hi:"IN",deva:"IN",te:"IN",mr:"IN",ta:"IN",gu:"IN",kn:"IN",or:"IN",ml:"IN",pa:"IN",bho:"IN",awa:"IN",as:"IN",mwr:"IN",mai:"IN",mag:"IN",bgc:"IN",hne:"IN",dcc:"IN",bn:"BD",beng:"BD",rkt:"BD",dz:"BT",tibt:"BT",tn:"BW",am:"ET",ethi:"ET",om:"ET",quc:"GT",id:"ID",jv:"ID",su:"ID",mad:"ID",ms_arab:"ID",he:"IL",hebr:"IL",jam:"JM",ja:"JP",jpan:"JP",km:"KH",khmr:"KH",ko:"KR",kore:"KR",lo:"LA",laoo:"LA",mh:"MH",my:"MM",mymr:"MM",mt:"MT",ne:"NP",fil:"PH",ceb:"PH",ilo:"PH",ur:"PK",pa_arab:"PK",lah:"PK",ps:"PK",sd:"PK",skr:"PK",gn:"PY",th:"TH",thai:"TH",tts:"TH",zh_hant:"TW",hant:"TW",sm:"WS",zu:"ZA",sn:"ZW",arq:"DZ",ar:"EG",arab:"EG",arz:"EG",fa:"IR",az_arab:"IR",dv:"MV",thaa:"MV"},a={AG:0,ATG:0,28:0,AS:0,ASM:0,16:0,BD:0,BGD:0,50:0,BR:0,BRA:0,76:0,BS:0,BHS:0,44:0,BT:0,BTN:0,64:0,BW:0,BWA:0,72:0,BZ:0,BLZ:0,84:0,CA:0,CAN:0,124:0,CO:0,COL:0,170:0,DM:0,DMA:0,212:0,DO:0,DOM:0,214:0,ET:0,ETH:0,231:0,GT:0,GTM:0,320:0,GU:0,GUM:0,316:0,HK:0,HKG:0,344:0,HN:0,HND:0,340:0,ID:0,IDN:0,360:0,IL:0,ISR:0,376:0,IN:0,IND:0,356:0,JM:0,JAM:0,388:0,JP:0,JPN:0,392:0,KE:0,KEN:0,404:0,KH:0,KHM:0,116:0,KR:0,KOR:0,410:0,LA:0,LA0:0,418:0,MH:0,MHL:0,584:0,MM:0,MMR:0,104:0,MO:0,MAC:0,446:0,MT:0,MLT:0,470:0,MX:0,MEX:0,484:0,MZ:0,MOZ:0,508:0,NI:0,NIC:0,558:0,NP:0,NPL:0,524:0,PA:0,PAN:0,591:0,PE:0,PER:0,604:0,PH:0,PHL:0,608:0,PK:0,PAK:0,586:0,PR:0,PRI:0,630:0,PT:0,PRT:0,620:0,PY:0,PRY:0,600:0,SA:0,SAU:0,682:0,SG:0,SGP:0,702:0,SV:0,SLV:0,222:0,TH:0,THA:0,764:0,TT:0,TTO:0,780:0,TW:0,TWN:0,158:0,UM:0,UMI:0,581:0,US:0,USA:0,840:0,VE:0,VEN:0,862:0,VI:0,VIR:0,850:0,WS:0,WSM:0,882:0,YE:0,YEM:0,887:0,ZA:0,ZAF:0,710:0,ZW:0,ZWE:0,716:0,AE:6,ARE:6,784:6,AF:6,AFG:6,4:6,BH:6,BHR:6,48:6,DJ:6,DJI:6,262:6,DZ:6,DZA:6,12:6,EG:6,EGY:6,818:6,IQ:6,IRQ:6,368:6,IR:6,IRN:6,364:6,JO:6,JOR:6,400:6,KW:6,KWT:6,414:6,LY:6,LBY:6,434:6,OM:6,OMN:6,512:6,QA:6,QAT:6,634:6,SD:6,SDN:6,729:6,SY:6,SYR:6,760:6,MV:5,MDV:5,462:5};function o(t){return function(t,n,e){if(t){var r,a=t.toLowerCase().split(/[-_]/),o=a[0],u=o;if(a[1]&&4===a[1].length?(u+="_"+a[1],r=a[2]):r=a[1],r||(r=n[u]||n[o]),r)return function(t,n){var e=n["string"==typeof t?t.toUpperCase():t];return"number"==typeof e?e:1}(r.match(/^\d+$/)?Number(r):r,e)}return 1}(t,r,a)}},46375:function(t,n,e){e(87568)({target:"Math",stat:!0},{trunc:e(91723)})},6913:function(t,n,e){e.d(n,{q:function(){return a}});var r={};function a(){return r}},49518:function(t,n,e){e.d(n,{my:function(){return r},w4:function(){return a}});Math.pow(10,8);var r=6048e5,a=864e5},84006:function(t,n,e){e.d(n,{m:function(){return i}});var r=e(49518),a=e(93352),o=e(74396);function u(t){var n=(0,o.a)(t),e=new Date(Date.UTC(n.getFullYear(),n.getMonth(),n.getDate(),n.getHours(),n.getMinutes(),n.getSeconds(),n.getMilliseconds()));return e.setUTCFullYear(n.getFullYear()),+t-+e}function i(t,n){var e=(0,a.o)(t),o=(0,a.o)(n),i=+e-u(e),c=+o-u(o);return Math.round((i-c)/r.w4)}},81438:function(t,n,e){e.d(n,{c:function(){return o}});e(650);var r=e(84006),a=e(74396);function o(t,n){var e=(0,a.a)(t),o=(0,a.a)(n),i=u(e,o),c=Math.abs((0,r.m)(e,o));e.setDate(e.getDate()-i*c);var M=i*(c-Number(u(e,o)===-i));return 0===M?0:M}function u(t,n){var e=t.getFullYear()-n.getFullYear()||t.getMonth()-n.getMonth()||t.getDate()-n.getDate()||t.getHours()-n.getHours()||t.getMinutes()-n.getMinutes()||t.getSeconds()-n.getSeconds()||t.getMilliseconds()-n.getMilliseconds();return e<0?-1:e>0?1:e}},13518:function(t,n,e){e.d(n,{I:function(){return a}});e(46375);var r=e(81438);function a(t,n,e){var a,o=(0,r.c)(t,n)/7;return(a=null==e?void 0:e.roundingMethod,function(t){var n=(a?Math[a]:Math.trunc)(t);return 0===n?0:n})(o)}},93352:function(t,n,e){e.d(n,{o:function(){return a}});var r=e(74396);function a(t){var n=(0,r.a)(t);return n.setHours(0,0,0,0),n}},56994:function(t,n,e){e.d(n,{k:function(){return o}});var r=e(74396),a=e(6913);function o(t,n){var e,o,u,i,c,M,l=(0,a.q)(),s=null!==(e=null!==(o=null!==(u=null!==(i=null==n?void 0:n.weekStartsOn)&&void 0!==i?i:null==n||null===(c=n.locale)||void 0===c||null===(c=c.options)||void 0===c?void 0:c.weekStartsOn)&&void 0!==u?u:l.weekStartsOn)&&void 0!==o?o:null===(M=l.locale)||void 0===M||null===(M=M.options)||void 0===M?void 0:M.weekStartsOn)&&void 0!==e?e:0,f=(0,r.a)(t),I=f.getDay(),N=(I<s?7:0)+I-s;return f.setDate(f.getDate()-N),f.setHours(0,0,0,0),f}},74396:function(t,n,e){e.d(n,{a:function(){return a}});var r=e(67234);e(68113),e(58971);function a(t){var n=Object.prototype.toString.call(t);return t instanceof Date||"object"===(0,r.A)(t)&&"[object Date]"===n?new t.constructor(+t):"number"==typeof t||"[object Number]"===n||"string"==typeof t||"[object String]"===n?new Date(t):new Date(NaN)}}}]);