export const id=3644;export const ids=[3644];export const modules={3644:(e,t,a)=>{a.r(t),a.d(t,{HaFormSelect:()=>o});var s=a(5461),l=a(5081),d=a(8597),i=a(196),r=a(3167);a(3768);let o=(0,s.A)([(0,i.EM)("ha-form-select")],(function(e,t){return{F:class extends t{constructor(...t){super(...t),e(this)}},d:[{kind:"field",decorators:[(0,i.MZ)({attribute:!1})],key:"hass",value:void 0},{kind:"field",decorators:[(0,i.MZ)({attribute:!1})],key:"schema",value:void 0},{kind:"field",decorators:[(0,i.MZ)({attribute:!1})],key:"data",value:void 0},{kind:"field",decorators:[(0,i.MZ)()],key:"label",value:void 0},{kind:"field",decorators:[(0,i.MZ)()],key:"helper",value:void 0},{kind:"field",decorators:[(0,i.MZ)({type:Boolean})],key:"disabled",value(){return!1}},{kind:"field",key:"_selectSchema",value(){return(0,l.A)((e=>({select:{options:e.map((e=>({value:e[0],label:e[1]})))}})))}},{kind:"method",key:"render",value:function(){return d.qy`
      <ha-selector-select
        .hass=${this.hass}
        .schema=${this.schema}
        .value=${this.data}
        .label=${this.label}
        .helper=${this.helper}
        .disabled=${this.disabled}
        .required=${this.schema.required}
        .selector=${this._selectSchema(this.schema.options)}
        @value-changed=${this._valueChanged}
      ></ha-selector-select>
    `}},{kind:"method",key:"_valueChanged",value:function(e){e.stopPropagation();let t=e.detail.value;t!==this.data&&(""===t&&(t=void 0),(0,r.r)(this,"value-changed",{value:t}))}}]}}),d.WF)}};
//# sourceMappingURL=J7Xj4Ruk.js.map