export const id=6048;export const ids=[6048];export const modules={6048:(e,t,a)=>{a.r(t),a.d(t,{HaFormExpendable:()=>n});var i=a(5461),o=a(8597),s=a(196);a(3259);let n=(0,i.A)([(0,s.EM)("ha-form-expandable")],(function(e,t){return{F:class extends t{constructor(...t){super(...t),e(this)}},d:[{kind:"field",decorators:[(0,s.MZ)({attribute:!1})],key:"hass",value:void 0},{kind:"field",decorators:[(0,s.MZ)({attribute:!1})],key:"data",value:void 0},{kind:"field",decorators:[(0,s.MZ)({attribute:!1})],key:"schema",value:void 0},{kind:"field",decorators:[(0,s.MZ)({type:Boolean})],key:"disabled",value(){return!1}},{kind:"field",decorators:[(0,s.MZ)({attribute:!1})],key:"computeLabel",value:void 0},{kind:"field",decorators:[(0,s.MZ)({attribute:!1})],key:"computeHelper",value:void 0},{kind:"method",key:"_renderDescription",value:function(){const e=this.computeHelper?.(this.schema);return e?o.qy`<p>${e}</p>`:o.s6}},{kind:"field",key:"_computeLabel",value(){return(e,t,a)=>this.computeLabel?this.computeLabel(e,t,{...a,path:[...a?.path||[],this.schema.name]}):this.computeLabel}},{kind:"field",key:"_computeHelper",value(){return(e,t)=>this.computeHelper?this.computeHelper(e,{...t,path:[...t?.path||[],this.schema.name]}):this.computeHelper}},{kind:"method",key:"render",value:function(){return o.qy`
      <ha-expansion-panel outlined .expanded=${Boolean(this.schema.expanded)}>
        <div
          slot="header"
          role="heading"
          aria-level=${this.schema.headingLevel?.toString()??"3"}
        >
          ${this.schema.icon?o.qy` <ha-icon .icon=${this.schema.icon}></ha-icon> `:this.schema.iconPath?o.qy`
                  <ha-svg-icon .path=${this.schema.iconPath}></ha-svg-icon>
                `:o.s6}
          ${this.schema.title||this.computeLabel?.(this.schema)}
        </div>
        <div class="content">
          ${this._renderDescription()}
          <ha-form
            .hass=${this.hass}
            .data=${this.data}
            .schema=${this.schema.schema}
            .disabled=${this.disabled}
            .computeLabel=${this._computeLabel}
            .computeHelper=${this._computeHelper}
          ></ha-form>
        </div>
      </ha-expansion-panel>
    `}},{kind:"get",static:!0,key:"styles",value:function(){return o.AH`
      :host {
        display: flex !important;
        flex-direction: column;
      }
      :host ha-form {
        display: block;
      }
      .content {
        padding: 12px;
      }
      .content p {
        margin: 0 0 24px;
      }
      ha-expansion-panel {
        display: block;
        --expansion-panel-content-padding: 0;
        border-radius: 6px;
        --ha-card-border-radius: 6px;
      }
      ha-svg-icon,
      ha-icon {
        color: var(--secondary-text-color);
      }
    `}}]}}),o.WF)}};
//# sourceMappingURL=lr6nFOg-.js.map