/*! For license information please see HXKTEfz_.js.LICENSE.txt */
export const id=5337;export const ids=[5337];export const modules={5089:(t,e,i)=>{i.d(e,{n:()=>g});var s=i(6513),r=i(196),n=(i(4431),i(9013),i(7515),i(8597)),o=i(9760),a=i(4505),c=i(7371),l=i(8024);const h=(0,c.n)(n.WF);class d extends h{constructor(){super(...arguments),this.disabled=!1,this.type="text",this.isListItem=!0,this.href="",this.target=""}get isDisabled(){return this.disabled&&"link"!==this.type}willUpdate(t){this.href&&(this.type="link"),super.willUpdate(t)}render(){return this.renderListItem(n.qy`
      <md-item>
        <div slot="container">
          ${this.renderRipple()} ${this.renderFocusRing()}
        </div>
        <slot name="start" slot="start"></slot>
        <slot name="end" slot="end"></slot>
        ${this.renderBody()}
      </md-item>
    `)}renderListItem(t){const e="link"===this.type;let i;switch(this.type){case"link":i=a.eu`a`;break;case"button":i=a.eu`button`;break;default:i=a.eu`li`}const s="text"!==this.type,r=e&&this.target?this.target:n.s6;return a.qy`
      <${i}
        id="item"
        tabindex="${this.isDisabled||!s?-1:0}"
        ?disabled=${this.isDisabled}
        role="listitem"
        aria-selected=${this.ariaSelected||n.s6}
        aria-checked=${this.ariaChecked||n.s6}
        aria-expanded=${this.ariaExpanded||n.s6}
        aria-haspopup=${this.ariaHasPopup||n.s6}
        class="list-item ${(0,o.H)(this.getRenderClasses())}"
        href=${this.href||n.s6}
        target=${r}
        @focus=${this.onFocus}
      >${t}</${i}>
    `}renderRipple(){return"text"===this.type?n.s6:n.qy` <md-ripple
      part="ripple"
      for="item"
      ?disabled=${this.isDisabled}></md-ripple>`}renderFocusRing(){return"text"===this.type?n.s6:n.qy` <md-focus-ring
      @visibility-changed=${this.onFocusRingVisibilityChanged}
      part="focus-ring"
      for="item"
      inward></md-focus-ring>`}onFocusRingVisibilityChanged(t){}getRenderClasses(){return{disabled:this.isDisabled}}renderBody(){return n.qy`
      <slot></slot>
      <slot name="overline" slot="overline"></slot>
      <slot name="headline" slot="headline"></slot>
      <slot name="supporting-text" slot="supporting-text"></slot>
      <slot
        name="trailing-supporting-text"
        slot="trailing-supporting-text"></slot>
    `}onFocus(){-1===this.tabIndex&&this.dispatchEvent((0,l.cG)())}focus(){this.listItemRoot?.focus()}}d.shadowRootOptions={...n.WF.shadowRootOptions,delegatesFocus:!0},(0,s.Cg)([(0,r.MZ)({type:Boolean,reflect:!0})],d.prototype,"disabled",void 0),(0,s.Cg)([(0,r.MZ)({reflect:!0})],d.prototype,"type",void 0),(0,s.Cg)([(0,r.MZ)({type:Boolean,attribute:"md-list-item",reflect:!0})],d.prototype,"isListItem",void 0),(0,s.Cg)([(0,r.MZ)()],d.prototype,"href",void 0),(0,s.Cg)([(0,r.MZ)()],d.prototype,"target",void 0),(0,s.Cg)([(0,r.P)(".list-item")],d.prototype,"listItemRoot",void 0);const u=n.AH`:host{display:flex;-webkit-tap-highlight-color:rgba(0,0,0,0);--md-ripple-hover-color: var(--md-list-item-hover-state-layer-color, var(--md-sys-color-on-surface, #1d1b20));--md-ripple-hover-opacity: var(--md-list-item-hover-state-layer-opacity, 0.08);--md-ripple-pressed-color: var(--md-list-item-pressed-state-layer-color, var(--md-sys-color-on-surface, #1d1b20));--md-ripple-pressed-opacity: var(--md-list-item-pressed-state-layer-opacity, 0.12)}:host(:is([type=button]:not([disabled]),[type=link])){cursor:pointer}md-focus-ring{z-index:1;--md-focus-ring-shape: 8px}a,button,li{background:none;border:none;cursor:inherit;padding:0;margin:0;text-align:unset;text-decoration:none}.list-item{border-radius:inherit;display:flex;flex:1;max-width:inherit;min-width:inherit;outline:none;-webkit-tap-highlight-color:rgba(0,0,0,0);width:100%}.list-item.interactive{cursor:pointer}.list-item.disabled{opacity:var(--md-list-item-disabled-opacity, 0.3);pointer-events:none}[slot=container]{pointer-events:none}md-ripple{border-radius:inherit}md-item{border-radius:inherit;flex:1;height:100%;color:var(--md-list-item-label-text-color, var(--md-sys-color-on-surface, #1d1b20));font-family:var(--md-list-item-label-text-font, var(--md-sys-typescale-body-large-font, var(--md-ref-typeface-plain, Roboto)));font-size:var(--md-list-item-label-text-size, var(--md-sys-typescale-body-large-size, 1rem));line-height:var(--md-list-item-label-text-line-height, var(--md-sys-typescale-body-large-line-height, 1.5rem));font-weight:var(--md-list-item-label-text-weight, var(--md-sys-typescale-body-large-weight, var(--md-ref-typeface-weight-regular, 400)));min-height:var(--md-list-item-one-line-container-height, 56px);padding-top:var(--md-list-item-top-space, 12px);padding-bottom:var(--md-list-item-bottom-space, 12px);padding-inline-start:var(--md-list-item-leading-space, 16px);padding-inline-end:var(--md-list-item-trailing-space, 16px)}md-item[multiline]{min-height:var(--md-list-item-two-line-container-height, 72px)}[slot=supporting-text]{color:var(--md-list-item-supporting-text-color, var(--md-sys-color-on-surface-variant, #49454f));font-family:var(--md-list-item-supporting-text-font, var(--md-sys-typescale-body-medium-font, var(--md-ref-typeface-plain, Roboto)));font-size:var(--md-list-item-supporting-text-size, var(--md-sys-typescale-body-medium-size, 0.875rem));line-height:var(--md-list-item-supporting-text-line-height, var(--md-sys-typescale-body-medium-line-height, 1.25rem));font-weight:var(--md-list-item-supporting-text-weight, var(--md-sys-typescale-body-medium-weight, var(--md-ref-typeface-weight-regular, 400)))}[slot=trailing-supporting-text]{color:var(--md-list-item-trailing-supporting-text-color, var(--md-sys-color-on-surface-variant, #49454f));font-family:var(--md-list-item-trailing-supporting-text-font, var(--md-sys-typescale-label-small-font, var(--md-ref-typeface-plain, Roboto)));font-size:var(--md-list-item-trailing-supporting-text-size, var(--md-sys-typescale-label-small-size, 0.6875rem));line-height:var(--md-list-item-trailing-supporting-text-line-height, var(--md-sys-typescale-label-small-line-height, 1rem));font-weight:var(--md-list-item-trailing-supporting-text-weight, var(--md-sys-typescale-label-small-weight, var(--md-ref-typeface-weight-medium, 500)))}:is([slot=start],[slot=end])::slotted(*){fill:currentColor}[slot=start]{color:var(--md-list-item-leading-icon-color, var(--md-sys-color-on-surface-variant, #49454f))}[slot=end]{color:var(--md-list-item-trailing-icon-color, var(--md-sys-color-on-surface-variant, #49454f))}@media(forced-colors: active){.disabled slot{color:GrayText}.list-item.disabled{color:GrayText;opacity:1}}
`;let g=class extends d{};g.styles=[u],g=(0,s.Cg)([(0,r.EM)("md-list-item")],g)},8371:(t,e,i)=>{i.d(e,{Y:()=>h});var s=i(6513),r=i(196),n=i(8597),o=i(1134);const a=new Set(Object.values(o.U));class c extends n.WF{get items(){return this.listController.items}constructor(){super(),this.listController=new o.Z({isItem:t=>t.hasAttribute("md-list-item"),getPossibleItems:()=>this.slotItems,isRtl:()=>"rtl"===getComputedStyle(this).direction,deactivateItem:t=>{t.tabIndex=-1},activateItem:t=>{t.tabIndex=0},isNavigableKey:t=>a.has(t),isActivatable:t=>!t.disabled&&"text"!==t.type}),this.internals=this.attachInternals(),n.S$||(this.internals.role="list",this.addEventListener("keydown",this.listController.handleKeydown))}render(){return n.qy`
      <slot
        @deactivate-items=${this.listController.onDeactivateItems}
        @request-activation=${this.listController.onRequestActivation}
        @slotchange=${this.listController.onSlotchange}>
      </slot>
    `}activateNextItem(){return this.listController.activateNextItem()}activatePreviousItem(){return this.listController.activatePreviousItem()}}(0,s.Cg)([(0,r.KN)({flatten:!0})],c.prototype,"slotItems",void 0);const l=n.AH`:host{background:var(--md-list-container-color, var(--md-sys-color-surface, #fef7ff));color:unset;display:flex;flex-direction:column;outline:none;padding:8px 0;position:relative}
`;let h=class extends c{};h.styles=[l],h=(0,s.Cg)([(0,r.EM)("md-list")],h)},2223:(t,e,i)=>{function s(t){return Array.isArray?Array.isArray(t):"[object Array]"===u(t)}i.d(e,{A:()=>J});const r=1/0;function n(t){return null==t?"":function(t){if("string"==typeof t)return t;let e=t+"";return"0"==e&&1/t==-r?"-0":e}(t)}function o(t){return"string"==typeof t}function a(t){return"number"==typeof t}function c(t){return!0===t||!1===t||function(t){return l(t)&&null!==t}(t)&&"[object Boolean]"==u(t)}function l(t){return"object"==typeof t}function h(t){return null!=t}function d(t){return!t.trim().length}function u(t){return null==t?void 0===t?"[object Undefined]":"[object Null]":Object.prototype.toString.call(t)}const g=t=>`Missing ${t} property in key`,p=t=>`Property 'weight' in key '${t}' must be a positive integer`,m=Object.prototype.hasOwnProperty;class f{constructor(t){this._keys=[],this._keyMap={};let e=0;t.forEach((t=>{let i=y(t);this._keys.push(i),this._keyMap[i.id]=i,e+=i.weight})),this._keys.forEach((t=>{t.weight/=e}))}get(t){return this._keyMap[t]}keys(){return this._keys}toJSON(){return JSON.stringify(this._keys)}}function y(t){let e=null,i=null,r=null,n=1,a=null;if(o(t)||s(t))r=t,e=x(t),i=v(t);else{if(!m.call(t,"name"))throw new Error(g("name"));const s=t.name;if(r=s,m.call(t,"weight")&&(n=t.weight,n<=0))throw new Error(p(s));e=x(s),i=v(s),a=t.getFn}return{path:e,id:i,weight:n,src:r,getFn:a}}function x(t){return s(t)?t:t.split(".")}function v(t){return s(t)?t.join("."):t}var M={isCaseSensitive:!1,includeScore:!1,keys:[],shouldSort:!0,sortFn:(t,e)=>t.score===e.score?t.idx<e.idx?-1:1:t.score<e.score?-1:1,includeMatches:!1,findAllMatches:!1,minMatchCharLength:1,location:0,threshold:.6,distance:100,...{useExtendedSearch:!1,getFn:function(t,e){let i=[],r=!1;const l=(t,e,d)=>{if(h(t))if(e[d]){const u=t[e[d]];if(!h(u))return;if(d===e.length-1&&(o(u)||a(u)||c(u)))i.push(n(u));else if(s(u)){r=!0;for(let t=0,i=u.length;t<i;t+=1)l(u[t],e,d+1)}else e.length&&l(u,e,d+1)}else i.push(t)};return l(t,o(e)?e.split("."):e,0),r?i:i[0]},ignoreLocation:!1,ignoreFieldNorm:!1,fieldNormWeight:1}};const b=/[^ ]+/g;class w{constructor({getFn:t=M.getFn,fieldNormWeight:e=M.fieldNormWeight}={}){this.norm=function(t=1,e=3){const i=new Map,s=Math.pow(10,e);return{get(e){const r=e.match(b).length;if(i.has(r))return i.get(r);const n=1/Math.pow(r,.5*t),o=parseFloat(Math.round(n*s)/s);return i.set(r,o),o},clear(){i.clear()}}}(e,3),this.getFn=t,this.isCreated=!1,this.setIndexRecords()}setSources(t=[]){this.docs=t}setIndexRecords(t=[]){this.records=t}setKeys(t=[]){this.keys=t,this._keysMap={},t.forEach(((t,e)=>{this._keysMap[t.id]=e}))}create(){!this.isCreated&&this.docs.length&&(this.isCreated=!0,o(this.docs[0])?this.docs.forEach(((t,e)=>{this._addString(t,e)})):this.docs.forEach(((t,e)=>{this._addObject(t,e)})),this.norm.clear())}add(t){const e=this.size();o(t)?this._addString(t,e):this._addObject(t,e)}removeAt(t){this.records.splice(t,1);for(let e=t,i=this.size();e<i;e+=1)this.records[e].i-=1}getValueForItemAtKeyId(t,e){return t[this._keysMap[e]]}size(){return this.records.length}_addString(t,e){if(!h(t)||d(t))return;let i={v:t,i:e,n:this.norm.get(t)};this.records.push(i)}_addObject(t,e){let i={i:e,$:{}};this.keys.forEach(((e,r)=>{let n=e.getFn?e.getFn(t):this.getFn(t,e.path);if(h(n))if(s(n)){let t=[];const e=[{nestedArrIndex:-1,value:n}];for(;e.length;){const{nestedArrIndex:i,value:r}=e.pop();if(h(r))if(o(r)&&!d(r)){let e={v:r,i:i,n:this.norm.get(r)};t.push(e)}else s(r)&&r.forEach(((t,i)=>{e.push({nestedArrIndex:i,value:t})}))}i.$[r]=t}else if(o(n)&&!d(n)){let t={v:n,n:this.norm.get(n)};i.$[r]=t}})),this.records.push(i)}toJSON(){return{keys:this.keys,records:this.records}}}function k(t,e,{getFn:i=M.getFn,fieldNormWeight:s=M.fieldNormWeight}={}){const r=new w({getFn:i,fieldNormWeight:s});return r.setKeys(t.map(y)),r.setSources(e),r.create(),r}function L(t,{errors:e=0,currentLocation:i=0,expectedLocation:s=0,distance:r=M.distance,ignoreLocation:n=M.ignoreLocation}={}){const o=e/t.length;if(n)return o;const a=Math.abs(s-i);return r?o+a/r:a?1:o}const C=32;function I(t,e,i,{location:s=M.location,distance:r=M.distance,threshold:n=M.threshold,findAllMatches:o=M.findAllMatches,minMatchCharLength:a=M.minMatchCharLength,includeMatches:c=M.includeMatches,ignoreLocation:l=M.ignoreLocation}={}){if(e.length>C)throw new Error(`Pattern length exceeds max of ${C}.`);const h=e.length,d=t.length,u=Math.max(0,Math.min(s,d));let g=n,p=u;const m=a>1||c,f=m?Array(d):[];let y;for(;(y=t.indexOf(e,p))>-1;){let t=L(e,{currentLocation:y,expectedLocation:u,distance:r,ignoreLocation:l});if(g=Math.min(t,g),p=y+h,m){let t=0;for(;t<h;)f[y+t]=1,t+=1}}p=-1;let x=[],v=1,b=h+d;const w=1<<h-1;for(let M=0;M<h;M+=1){let s=0,n=b;for(;s<n;){L(e,{errors:M,currentLocation:u+n,expectedLocation:u,distance:r,ignoreLocation:l})<=g?s=n:b=n,n=Math.floor((b-s)/2+s)}b=n;let a=Math.max(1,u-n+1),c=o?d:Math.min(u+n,d)+h,y=Array(c+2);y[c+1]=(1<<M)-1;for(let o=c;o>=a;o-=1){let s=o-1,n=i[t.charAt(s)];if(m&&(f[s]=+!!n),y[o]=(y[o+1]<<1|1)&n,M&&(y[o]|=(x[o+1]|x[o])<<1|1|x[o+1]),y[o]&w&&(v=L(e,{errors:M,currentLocation:s,expectedLocation:u,distance:r,ignoreLocation:l}),v<=g)){if(g=v,p=s,p<=u)break;a=Math.max(1,2*u-p)}}if(L(e,{errors:M+1,currentLocation:u,expectedLocation:u,distance:r,ignoreLocation:l})>g)break;x=y}const k={isMatch:p>=0,score:Math.max(.001,v)};if(m){const t=function(t=[],e=M.minMatchCharLength){let i=[],s=-1,r=-1,n=0;for(let o=t.length;n<o;n+=1){let o=t[n];o&&-1===s?s=n:o||-1===s||(r=n-1,r-s+1>=e&&i.push([s,r]),s=-1)}return t[n-1]&&n-s>=e&&i.push([s,n-1]),i}(f,a);t.length?c&&(k.indices=t):k.isMatch=!1}return k}function $(t){let e={};for(let i=0,s=t.length;i<s;i+=1){const r=t.charAt(i);e[r]=(e[r]||0)|1<<s-i-1}return e}class S{constructor(t,{location:e=M.location,threshold:i=M.threshold,distance:s=M.distance,includeMatches:r=M.includeMatches,findAllMatches:n=M.findAllMatches,minMatchCharLength:o=M.minMatchCharLength,isCaseSensitive:a=M.isCaseSensitive,ignoreLocation:c=M.ignoreLocation}={}){if(this.options={location:e,threshold:i,distance:s,includeMatches:r,findAllMatches:n,minMatchCharLength:o,isCaseSensitive:a,ignoreLocation:c},this.pattern=a?t:t.toLowerCase(),this.chunks=[],!this.pattern.length)return;const l=(t,e)=>{this.chunks.push({pattern:t,alphabet:$(t),startIndex:e})},h=this.pattern.length;if(h>C){let t=0;const e=h%C,i=h-e;for(;t<i;)l(this.pattern.substr(t,C),t),t+=C;if(e){const t=h-C;l(this.pattern.substr(t),t)}}else l(this.pattern,0)}searchIn(t){const{isCaseSensitive:e,includeMatches:i}=this.options;if(e||(t=t.toLowerCase()),this.pattern===t){let e={isMatch:!0,score:0};return i&&(e.indices=[[0,t.length-1]]),e}const{location:s,distance:r,threshold:n,findAllMatches:o,minMatchCharLength:a,ignoreLocation:c}=this.options;let l=[],h=0,d=!1;this.chunks.forEach((({pattern:e,alphabet:u,startIndex:g})=>{const{isMatch:p,score:m,indices:f}=I(t,e,u,{location:s+g,distance:r,threshold:n,findAllMatches:o,minMatchCharLength:a,includeMatches:i,ignoreLocation:c});p&&(d=!0),h+=m,p&&f&&(l=[...l,...f])}));let u={isMatch:d,score:d?h/this.chunks.length:1};return d&&i&&(u.indices=l),u}}class _{constructor(t){this.pattern=t}static isMultiMatch(t){return A(t,this.multiRegex)}static isSingleMatch(t){return A(t,this.singleRegex)}search(){}}function A(t,e){const i=t.match(e);return i?i[1]:null}class R extends _{constructor(t,{location:e=M.location,threshold:i=M.threshold,distance:s=M.distance,includeMatches:r=M.includeMatches,findAllMatches:n=M.findAllMatches,minMatchCharLength:o=M.minMatchCharLength,isCaseSensitive:a=M.isCaseSensitive,ignoreLocation:c=M.ignoreLocation}={}){super(t),this._bitapSearch=new S(t,{location:e,threshold:i,distance:s,includeMatches:r,findAllMatches:n,minMatchCharLength:o,isCaseSensitive:a,ignoreLocation:c})}static get type(){return"fuzzy"}static get multiRegex(){return/^"(.*)"$/}static get singleRegex(){return/^(.*)$/}search(t){return this._bitapSearch.searchIn(t)}}class F extends _{constructor(t){super(t)}static get type(){return"include"}static get multiRegex(){return/^'"(.*)"$/}static get singleRegex(){return/^'(.*)$/}search(t){let e,i=0;const s=[],r=this.pattern.length;for(;(e=t.indexOf(this.pattern,i))>-1;)i=e+r,s.push([e,i-1]);const n=!!s.length;return{isMatch:n,score:n?0:1,indices:s}}}const E=[class extends _{constructor(t){super(t)}static get type(){return"exact"}static get multiRegex(){return/^="(.*)"$/}static get singleRegex(){return/^=(.*)$/}search(t){const e=t===this.pattern;return{isMatch:e,score:e?0:1,indices:[0,this.pattern.length-1]}}},F,class extends _{constructor(t){super(t)}static get type(){return"prefix-exact"}static get multiRegex(){return/^\^"(.*)"$/}static get singleRegex(){return/^\^(.*)$/}search(t){const e=t.startsWith(this.pattern);return{isMatch:e,score:e?0:1,indices:[0,this.pattern.length-1]}}},class extends _{constructor(t){super(t)}static get type(){return"inverse-prefix-exact"}static get multiRegex(){return/^!\^"(.*)"$/}static get singleRegex(){return/^!\^(.*)$/}search(t){const e=!t.startsWith(this.pattern);return{isMatch:e,score:e?0:1,indices:[0,t.length-1]}}},class extends _{constructor(t){super(t)}static get type(){return"inverse-suffix-exact"}static get multiRegex(){return/^!"(.*)"\$$/}static get singleRegex(){return/^!(.*)\$$/}search(t){const e=!t.endsWith(this.pattern);return{isMatch:e,score:e?0:1,indices:[0,t.length-1]}}},class extends _{constructor(t){super(t)}static get type(){return"suffix-exact"}static get multiRegex(){return/^"(.*)"\$$/}static get singleRegex(){return/^(.*)\$$/}search(t){const e=t.endsWith(this.pattern);return{isMatch:e,score:e?0:1,indices:[t.length-this.pattern.length,t.length-1]}}},class extends _{constructor(t){super(t)}static get type(){return"inverse-exact"}static get multiRegex(){return/^!"(.*)"$/}static get singleRegex(){return/^!(.*)$/}search(t){const e=-1===t.indexOf(this.pattern);return{isMatch:e,score:e?0:1,indices:[0,t.length-1]}}},R],N=E.length,O=/ +(?=(?:[^\"]*\"[^\"]*\")*[^\"]*$)/;const W=new Set([R.type,F.type]);class j{constructor(t,{isCaseSensitive:e=M.isCaseSensitive,includeMatches:i=M.includeMatches,minMatchCharLength:s=M.minMatchCharLength,ignoreLocation:r=M.ignoreLocation,findAllMatches:n=M.findAllMatches,location:o=M.location,threshold:a=M.threshold,distance:c=M.distance}={}){this.query=null,this.options={isCaseSensitive:e,includeMatches:i,minMatchCharLength:s,findAllMatches:n,ignoreLocation:r,location:o,threshold:a,distance:c},this.pattern=e?t:t.toLowerCase(),this.query=function(t,e={}){return t.split("|").map((t=>{let i=t.trim().split(O).filter((t=>t&&!!t.trim())),s=[];for(let r=0,n=i.length;r<n;r+=1){const t=i[r];let n=!1,o=-1;for(;!n&&++o<N;){const i=E[o];let r=i.isMultiMatch(t);r&&(s.push(new i(r,e)),n=!0)}if(!n)for(o=-1;++o<N;){const i=E[o];let r=i.isSingleMatch(t);if(r){s.push(new i(r,e));break}}}return s}))}(this.pattern,this.options)}static condition(t,e){return e.useExtendedSearch}searchIn(t){const e=this.query;if(!e)return{isMatch:!1,score:1};const{includeMatches:i,isCaseSensitive:s}=this.options;t=s?t:t.toLowerCase();let r=0,n=[],o=0;for(let a=0,c=e.length;a<c;a+=1){const s=e[a];n.length=0,r=0;for(let e=0,a=s.length;e<a;e+=1){const a=s[e],{isMatch:c,indices:l,score:h}=a.search(t);if(!c){o=0,r=0,n.length=0;break}if(r+=1,o+=h,i){const t=a.constructor.type;W.has(t)?n=[...n,...l]:n.push(l)}}if(r){let t={isMatch:!0,score:o/r};return i&&(t.indices=n),t}}return{isMatch:!1,score:1}}}const z=[];function q(t,e){for(let i=0,s=z.length;i<s;i+=1){let s=z[i];if(s.condition(t,e))return new s(t,e)}return new S(t,e)}const P="$and",K="$or",D="$path",Z="$val",B=t=>!(!t[P]&&!t[K]),H=t=>({[P]:Object.keys(t).map((e=>({[e]:t[e]})))});function U(t,e,{auto:i=!0}={}){const r=t=>{let n=Object.keys(t);const a=(t=>!!t[D])(t);if(!a&&n.length>1&&!B(t))return r(H(t));if((t=>!s(t)&&l(t)&&!B(t))(t)){const s=a?t[D]:n[0],r=a?t[Z]:t[s];if(!o(r))throw new Error((t=>`Invalid value for key ${t}`)(s));const c={keyId:v(s),pattern:r};return i&&(c.searcher=q(r,e)),c}let c={children:[],operator:n[0]};return n.forEach((e=>{const i=t[e];s(i)&&i.forEach((t=>{c.children.push(r(t))}))})),c};return B(t)||(t=H(t)),r(t)}function V(t,e){const i=t.matches;e.matches=[],h(i)&&i.forEach((t=>{if(!h(t.indices)||!t.indices.length)return;const{indices:i,value:s}=t;let r={indices:i,value:s};t.key&&(r.key=t.key.src),t.idx>-1&&(r.refIndex=t.idx),e.matches.push(r)}))}function G(t,e){e.score=t.score}class J{constructor(t,e={},i){this.options={...M,...e},this.options.useExtendedSearch,this._keyStore=new f(this.options.keys),this.setCollection(t,i)}setCollection(t,e){if(this._docs=t,e&&!(e instanceof w))throw new Error("Incorrect 'index' type");this._myIndex=e||k(this.options.keys,this._docs,{getFn:this.options.getFn,fieldNormWeight:this.options.fieldNormWeight})}add(t){h(t)&&(this._docs.push(t),this._myIndex.add(t))}remove(t=(()=>!1)){const e=[];for(let i=0,s=this._docs.length;i<s;i+=1){const r=this._docs[i];t(r,i)&&(this.removeAt(i),i-=1,s-=1,e.push(r))}return e}removeAt(t){this._docs.splice(t,1),this._myIndex.removeAt(t)}getIndex(){return this._myIndex}search(t,{limit:e=-1}={}){const{includeMatches:i,includeScore:s,shouldSort:r,sortFn:n,ignoreFieldNorm:c}=this.options;let l=o(t)?o(this._docs[0])?this._searchStringList(t):this._searchObjectList(t):this._searchLogical(t);return function(t,{ignoreFieldNorm:e=M.ignoreFieldNorm}){t.forEach((t=>{let i=1;t.matches.forEach((({key:t,norm:s,score:r})=>{const n=t?t.weight:null;i*=Math.pow(0===r&&n?Number.EPSILON:r,(n||1)*(e?1:s))})),t.score=i}))}(l,{ignoreFieldNorm:c}),r&&l.sort(n),a(e)&&e>-1&&(l=l.slice(0,e)),function(t,e,{includeMatches:i=M.includeMatches,includeScore:s=M.includeScore}={}){const r=[];return i&&r.push(V),s&&r.push(G),t.map((t=>{const{idx:i}=t,s={item:e[i],refIndex:i};return r.length&&r.forEach((e=>{e(t,s)})),s}))}(l,this._docs,{includeMatches:i,includeScore:s})}_searchStringList(t){const e=q(t,this.options),{records:i}=this._myIndex,s=[];return i.forEach((({v:t,i:i,n:r})=>{if(!h(t))return;const{isMatch:n,score:o,indices:a}=e.searchIn(t);n&&s.push({item:t,idx:i,matches:[{score:o,value:t,norm:r,indices:a}]})})),s}_searchLogical(t){const e=U(t,this.options),i=(t,e,s)=>{if(!t.children){const{keyId:i,searcher:r}=t,n=this._findMatches({key:this._keyStore.get(i),value:this._myIndex.getValueForItemAtKeyId(e,i),searcher:r});return n&&n.length?[{idx:s,item:e,matches:n}]:[]}const r=[];for(let n=0,o=t.children.length;n<o;n+=1){const o=t.children[n],a=i(o,e,s);if(a.length)r.push(...a);else if(t.operator===P)return[]}return r},s=this._myIndex.records,r={},n=[];return s.forEach((({$:t,i:s})=>{if(h(t)){let o=i(e,t,s);o.length&&(r[s]||(r[s]={idx:s,item:t,matches:[]},n.push(r[s])),o.forEach((({matches:t})=>{r[s].matches.push(...t)})))}})),n}_searchObjectList(t){const e=q(t,this.options),{keys:i,records:s}=this._myIndex,r=[];return s.forEach((({$:t,i:s})=>{if(!h(t))return;let n=[];i.forEach(((i,s)=>{n.push(...this._findMatches({key:i,value:t[s],searcher:e}))})),n.length&&r.push({idx:s,item:t,matches:n})})),r}_findMatches({key:t,value:e,searcher:i}){if(!h(e))return[];let r=[];if(s(e))e.forEach((({v:e,i:s,n:n})=>{if(!h(e))return;const{isMatch:o,score:a,indices:c}=i.searchIn(e);o&&r.push({score:a,key:t,value:e,idx:s,norm:n,indices:c})}));else{const{v:s,n:n}=e,{isMatch:o,score:a,indices:c}=i.searchIn(s);o&&r.push({score:a,key:t,value:s,norm:n,indices:c})}return r}}J.version="7.0.0",J.createIndex=k,J.parseIndex=function(t,{getFn:e=M.getFn,fieldNormWeight:i=M.fieldNormWeight}={}){const{keys:s,records:r}=t,n=new w({getFn:e,fieldNormWeight:i});return n.setKeys(s),n.setIndexRecords(r),n},J.config=M,J.parseQuery=U,function(...t){z.push(...t)}(j)}};
//# sourceMappingURL=HXKTEfz_.js.map