"use strict";(self.webpackChunkknx_frontend=self.webpackChunkknx_frontend||[]).push([[376],{97995:function(n,t,e){e.d(t,{R:function(){return m}});e(77052),e(53156),e(36724),e(59092),e(68113),e(26777),e(73842),e(66274),e(98168),e(22836),e(7133),e(66123);var i,r=e(6238),a=(e(21950),e(71936),e(43618),e(58971),e(57733),e(18404),e(14178),e(5787),e(19394),e(92289),e(61350),e(35832),e(56262),e(8339),e(98597)),o=(e(12506),e(29222),new Set(["clear-night","cloudy","fog","lightning","lightning-rainy","partlycloudy","pouring","rainy","hail","snowy","snowy-rainy","sunny","windy","windy-variant"]),new Set(["partlycloudy","cloudy","fog","windy","windy-variant","hail","rainy","snowy","snowy-rainy","pouring","lightning","lightning-rainy"]),new Set(["hail","rainy","pouring"]),new Set(["windy","windy-variant"]),new Set(["snowy","snowy-rainy"]),new Set(["lightning","lightning-rainy"]),(0,a.AH)(i||(i=(0,r.A)(["\n  .rain {\n    fill: var(--weather-icon-rain-color, #30b3ff);\n  }\n  .sun {\n    fill: var(--weather-icon-sun-color, #fdd93c);\n  }\n  .moon {\n    fill: var(--weather-icon-moon-color, #fcf497);\n  }\n  .cloud-back {\n    fill: var(--weather-icon-cloud-back-color, #d4d4d4);\n  }\n  .cloud-front {\n    fill: var(--weather-icon-cloud-front-color, #f9f9f9);\n  }\n  .snow {\n    fill: var(--weather-icon-snow-color, #f9f9f9);\n    stroke: var(--weather-icon-snow-stroke-color, #d4d4d4);\n    stroke-width: 1;\n    paint-order: stroke;\n  }\n"]))),e(79076),e(37491),e(17963),e(1695)),c=(e(44186),e(90591),e(16915),e(4148),"^\\d{4}-(0[1-9]|1[0-2])-([12]\\d|0[1-9]|3[01])"),u=(new RegExp(c+"$"),new RegExp(c),e(19263)),m=(e(80085),function(n,t,e,i){var r=t.entity_id,a=t.attributes.device_class,c=(0,u.m)(r),m=e[r],l=null==m?void 0:m.translation_key;return l&&n("component.".concat(m.platform,".entity.").concat(c,".").concat(l,".state_attributes.").concat(i,".name"))||a&&n("component.".concat(c,".entity_component.").concat(a,".state_attributes.").concat(i,".name"))||n("component.".concat(c,".entity_component._.state_attributes.").concat(i,".name"))||(0,o.Z)(i.replace(/_/g," ").replace(/\bid\b/g,"ID").replace(/\bip\b/g,"IP").replace(/\bmac\b/g,"MAC").replace(/\bgps\b/g,"GPS"))})},17963:function(n,t,e){e.d(t,{ZV:function(){return r}});e(77052),e(53501),e(75658),e(650),e(53183),e(60212),e(43859),e(68113),e(58971),e(34517);var i=e(99096),r=function(n,t,e){var r=t?function(n){switch(n.number_format){case i.jG.comma_decimal:return["en-US","en"];case i.jG.decimal_comma:return["de","es","it"];case i.jG.space_comma:return["fr","sv","cs"];case i.jG.system:return;default:return n.language}}(t):void 0;return Number.isNaN=Number.isNaN||function n(t){return"number"==typeof t&&n(t)},(null==t?void 0:t.number_format)===i.jG.none||Number.isNaN(Number(n))?Number.isNaN(Number(n))||""===n||(null==t?void 0:t.number_format)!==i.jG.none?"string"==typeof n?n:"".concat(function(n){var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:2;return Math.round(n*Math.pow(10,t))/Math.pow(10,t)}(n,null==e?void 0:e.maximumFractionDigits).toString()).concat("currency"===(null==e?void 0:e.style)?" ".concat(e.currency):""):new Intl.NumberFormat("en-US",a(n,Object.assign(Object.assign({},e),{},{useGrouping:!1}))).format(Number(n)):new Intl.NumberFormat(r,a(n,e)).format(Number(n))},a=function(n,t){var e=Object.assign({maximumFractionDigits:2},t);if("string"!=typeof n)return e;if(!t||void 0===t.minimumFractionDigits&&void 0===t.maximumFractionDigits){var i=n.indexOf(".")>-1?n.split(".")[1].length:0;e.minimumFractionDigits=i,e.maximumFractionDigits=i}return e}},1695:function(n,t,e){e.d(t,{Z:function(){return i}});e(98828);var i=function(n){return n.charAt(0).toUpperCase()+n.slice(1)}},7133:function(n,t,e){e.d(t,{rM:function(){return i}});e(21950),e(68113),e(58971),e(57733),e(18404),e(14178),e(5787),e(19394),e(92289),e(61350),e(35832),e(56262),e(8339),e(86245),e(77052),e(43618);new Set(["temperature","current_temperature","target_temperature","target_temp_temp","target_temp_high","target_temp_low","target_temp_step","min_temp","max_temp"]);var i={climate:{humidity:"%",current_humidity:"%",target_humidity_low:"%",target_humidity_high:"%",target_humidity_step:"%",min_humidity:"%",max_humidity:"%"},cover:{current_position:"%",current_tilt_position:"%"},fan:{percentage:"%"},humidifier:{humidity:"%",current_humidity:"%",min_humidity:"%",max_humidity:"%"},light:{color_temp:"mired",max_mireds:"mired",min_mireds:"mired",color_temp_kelvin:"K",min_color_temp_kelvin:"K",max_color_temp_kelvin:"K",brightness:"%"},sun:{azimuth:"°",elevation:"°"},vacuum:{battery_level:"%"},valve:{current_position:"%"},sensor:{battery_level:"%"},media_player:{volume_level:"%"}}}}]);